@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# written by Christoph Federrath, 2019-2022
+# written by Christoph Federrath, 2019-2023
 
 import numpy as np
 np.set_printoptions(linewidth=200) # increase the numpy printing linewidth a bit
@@ -256,6 +256,13 @@ def fit(func, xdata, ydata, weights=None, params=None, verbose=1, *args, **kwarg
 
 # === END fit ===
 
+# === START get_hostname ===
+def get_hostname():
+    import socket
+    hostname = socket.gethostname()
+    return hostname
+# === END get_hostname ===
+
 # === Decorator to print the runtime of the decorated function ===
 def timer_decorator(func):
     from functools import wraps
@@ -698,10 +705,10 @@ def shock_jump_T(Mach, gamma=5.0/3.0):
 # or face-centred if keyword cell_centred=False
 def get_1d_coords(cmin=0, cmax=1, ndim=10, cell_centred=True):
     if cell_centred:
-        d = (cmax-cmin) / np.float(ndim)
+        d = (cmax-cmin) / float(ndim)
         offset = d/2
     else:
-        d = (cmax-cmin) / np.float(ndim-1)
+        d = (cmax-cmin) / float(ndim-1)
         offset = 0.0
     return np.linspace(cmin+offset, cmax-offset, num=ndim)
 
